natural_abundance_correction returns the corrected and normalized
intensities of isotopically labeled mass spectrometry data. It was designed
to work with input data from
El-MAVEN and
MAVEN software.
natural_abundance_correction(
data,
sheet = NULL,
compound_database = NULL,
output_base = NULL,
output_filetype = "xlsx",
columns_to_skip = NULL,
resolution,
resolution_defined_at = 200,
purity = NULL,
report_pool_size_before_df = FALSE,
path = NULL
)Named list of matrices: 'Corrected', 'Normalized', 'PoolBeforeDF', and 'PoolAfterDF'.
Path to input data file (xlsx, xls, csv, txt, or tsv) OR dataframe. If dataframe is specified, specify output_base to output files automatically written.
Name of sheet in xlsx file with columns 'compound', 'formula', 'isotopelabel', and one column per sample. Defaults to the first sheet.
Path to compound database in csv format. Only used for classic MAVEN style input when formula is not specified.
Path to basename of output file, default is the basename of the input path. `_corrected` will be appended. If `FALSE` then no output file is written.
Filetype of the output file, one of: 'xls', xlsx', 'csv', or 'tsv'. The default is 'xlsx'.
Specify column heading to skip. All other columns not named 'compound', 'formula', and 'isotopelabel' will be assumed to be sample names.
For Exactive, the resolution is 100000, defined at Mw 200
Mw at which the resolution is defined, default 200 Mw
Isotope purity, default: Carbon 0.99; Deuterium 0.98; Nitrogen 0.99
Report PoolSizeBeforeDF, default = FALSE
Deprecated. Specify path to input data file (alias for `data`).
C13, H2, and N15 isotopes are supported. The isotopes are detected from the
isotopeLabel column of the input file. The expected label text is
C13-label-#. D-label-#. or N15-label-#. Parent
(unlabeled) compounds are specified by C12 PARENT.
if (FALSE) {
natural_abundance_correction("inst/extdata/C_Sample_Input_Simple.xlsx",
Resolution = 100000, ResDefAt = 200
)
}
Run the code above in your browser using DataLab